Identify amino acid changes associated with single nucleotide variation. Changes associated with indels are identified in separate function. Used by call_mutations() function.
id_snps(variant.calls, ref, code.num = "1")Data frame that includes amino acid calls based on SNP/SNV variants observed in sample. Contains cols "POS", "REF_BASE", "GENE", "REF_CODON", "REF_AA", "GENE_AA_POS", "REF_IDENT", "REF", "ALT", "ALT_freq", "ALT_COUNT", "samp_codon", "samp_AA", "samp_identity", "DP"
Data frame with cols POS, REF, ALT, AF (alt freq), DP (total read depth).
reference genome in "MixVir" format (from create_ref() function)
Number defining the genetic code to use for translation